==> http-client-basics-1.16.2-sources.jar: org/dmfs/httpessentials/entities/DelegatingRequestEntity.java <==
/*
 * Copyright 2017 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dmfs.httpessentials.entities;

import org.dmfs.httpessentials.client.HttpRequestEntity;
import org.dmfs.httpessentials.types.MediaType;
import org.dmfs.optional.Optional;

import java.io.IOException;
import java.io.OutputStream;


/**
 * An abstract {@link HttpRequestEntity} which delegates all calls to another {@link HttpRequestEntity}.
 *
 * @author Marten Gajda
 */
public abstract class DelegatingRequestEntity implements HttpRequestEntity
{
    private final HttpRequestEntity mDelegate;


    public DelegatingRequestEntity(HttpRequestEntity delegate)
    {
        mDelegate = delegate;
    }


    @Override
    public final Optional<MediaType> contentType()
    {
        return mDelegate.contentType();
    }


    @Override
    public final Optional<Long> contentLength()
    {
        return mDelegate.contentLength();
    }


    @Override
    public final void writeContent(OutputStream out) throws IOException
    {
        mDelegate.writeContent(out);
    }
}

==> http-client-basics-1.22.1-sources.jar: org/dmfs/httpessentials/entities/DelegatingRequestEntity.java <==
/*
 * Copyright 2017 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dmfs.httpessentials.entities;

import org.dmfs.httpessentials.client.HttpRequestEntity;
import org.dmfs.httpessentials.types.MediaType;
import org.dmfs.jems.optional.Optional;

import java.io.IOException;
import java.io.OutputStream;


/**
 * An abstract {@link HttpRequestEntity} which delegates all calls to another {@link HttpRequestEntity}.
 *
 * @author Marten Gajda
 */
public abstract class DelegatingRequestEntity implements HttpRequestEntity
{
    private final HttpRequestEntity mDelegate;


    public DelegatingRequestEntity(HttpRequestEntity delegate)
    {
        mDelegate = delegate;
    }


    @Override
    public final Optional<MediaType> contentType()
    {
        return mDelegate.contentType();
    }


    @Override
    public final Optional<Long> contentLength()
    {
        return mDelegate.contentLength();
    }


    @Override
    public final void writeContent(OutputStream out) throws IOException
    {
        mDelegate.writeContent(out);
    }
}
